@@ -82,8 +82,9 @@ def report_errors(f):
         try:
             f(*args, **kwds)
         except:
+            version = pkg_resources.get_distribution("gigalixir").version
+            rollbar.report_exc_info(sys.exc_info(), payload_data={"version": version})
             logging.getLogger("gigalixir-cli").error(sys.exc_info()[1])
-            rollbar.report_exc_info(sys.exc_info(), payload_data={'fingerprint': rollbar_fingerprint(sys.exc_info())})
             sys.exit(1)
     return wrapper
 
@@ -350,7 +351,7 @@ def remote_console(ctx, app_name, ssh_opts, ssh_cmd):
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.argument('command', nargs=-1)
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
@@ -364,7 +365,7 @@ def ps_run(ctx, app_name, ssh_opts, ssh_cmd, command):
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.argument('command', nargs=-1)
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
@@ -378,7 +379,7 @@ def ssh(ctx, app_name, ssh_opts, ssh_cmd, command):
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.argument('distillery_command', nargs=-1)
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
@@ -417,7 +418,7 @@ def run(ctx, app_name, command):
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.option('-m', '--migration_app_name', default=None, help='For umbrella apps, specify which inner app to migrate.')
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
@@ -1063,7 +1064,7 @@ def signup(ctx, email, password, accept_terms_of_service_and_privacy_policy):
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.option('-c', '--cookie')
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
